<?php


namespace Daemon;


use Api\PhpServices\Daemon\DaemonServiceInterface;
use Api\PhpUtils\Log\DaemonLog;
use App\Services\marketing\MarketingService;
use Api\PhpServices\Wechat\Msg;

class Pindan implements DaemonServiceInterface
{
    const DEFAULT_DESC = '9.9元吃午餐开始预定啦，戳这里点餐吧';

    public function run()
    {
        //只在16:40执行逻辑
        if(date('H') != 16 || date('i')!= 40) {
            sleep(5);
            return false;
        }

        try{
            //查询进行中的拼单活动
            $params['marketing_type'] = 4;//1分销 2团购 3秒杀 4团餐
            $params['online_status'] = 1;//状态 ， 1启用，2关闭，3 到期
            $params['activity_status'] = 2;//1 未开始，2进行中，3已结束
            $params['page'] = 1;
            $params['page_size'] = 1;
            $list = MarketingService::marketingList($params);

            if(empty($list['result'])) {
                DaemonLog::info(
                    'DaemonServiceInterface_pindan',
                    'no need to send at'.date('Y-m-d H:i:s')
                );
                sleep(60);
                return false;
            }

            //给订阅用户发送消息
            //http://ydwiki.yidian-inc.com/pages/viewpage.action?pageId=71667995
            $app_id = 'wx4e0d92499185fb74';
            $template_id = 'LqGgPLdQPh2CHAFN1B8UK7NVc4LQt2zpjOZoyNuwaEI';
            $page_url = '/pages/home/index?messageNotify=1';
            $type = 2; // 1 公众号 2 小程序
            //活动信息
            $params = [
                self::emojiFilter($list['result'][0]['marketing_name']),
                $list['result'][0]['create_time'],
                $list['result'][0]['pindan_desc'] ?: self::DEFAULT_DESC
            ];
            //发送消息
            DaemonLog::info(
                'DaemonServiceInterface_pindan',
                'send at '.date('Y-m-d H:i:s').' params:'.json_encode($params)
            );
            Msg::send(999, $app_id, $template_id, $page_url, $type, $params);

            sleep(60);//保证16:40只执行一次
        }catch (Exception $e) {
            DaemonLog::error(
                'DaemonServiceInterface_pindan',
                'params:'.json_encode($params).' exception:'.$e->getMessage()
            );
        }
    }

    /**
     * 过滤emoji表情
     * @param string $str
     * @return string
     */
    private function emojiFilter($str) {
        $str = preg_replace_callback('/./u',function(array $match){
            return strlen($match[0]) >= 4 ? '' : $match[0];
        },$str);

        return $str;
    }
}